@@ -79,14 +79,6 @@ class ModelHub:
         """
         return self._conversion_events
 
-    @staticmethod
-    def _check_data_is_objectiv_data(data: bach.DataFrame):
-        """
-        Validates that provided DataFrame is a representation of an objectiv dataframe.
-        """
-        from modelhub.stack.util import check_objectiv_dataframe
-        check_objectiv_dataframe(data, check_index=True, check_dtypes=True, with_md_dtypes=True)
-
     @staticmethod
     def _get_db_engine(db_url: Optional[str], bq_credentials_path: Optional[str] = None) -> Engine:
         """
